@@ -78,6 +78,9 @@ membership of lipid *i* at frame *j*. Lipid *i*, at frame *j*, is in the upper
 leaflet if `leaflets.leaflets[i, j]==1` and in the lower leaflet if
 `leaflets.leaflets[i, j]==-1`.
 
+Allowing lipids in the midplane
+^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
+
 The above example will assign every lipid (including sterols) to either the upper
 or lower leaflet. To allow cholesterol to be in the midplane, we can provide
 a :attr:`midplane_sel` and :attr:`midplane_cutoff` to :class:`AssignLeaflets`::
@@ -93,13 +96,16 @@ A cholesterol molecule that has both its *ROH* and *C2* atoms within *12* Å of
 membrane midpoint will be assigned to the midplane, i.e. for cholesterol *i*
 at frame *j* that is in the midplane, `leaflets.leaflets[i, j]==0`.
 
+Changing the resolution of the membrane grid
+^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
+
 The first two examples compute a global membrane midpoint based on all the atoms
-of the lipids in the. Lipids are then assigned a leaflet based on their distance
-in *z* to this midpoint. This is okay for planar bilayers, but can lead to incorrect
+of the lipids in the membrane. Lipids are then assigned a leaflet based on their distance
+in :math:`z` to this midpoint. This is okay for planar bilayers, but can lead to incorrect
 leaflet classification in membranes with large undulations. If your bilayer has
-large undulations, `AssignLeaflets` account for this by creating a grid in *xy*
-patches of your membrane, calculating the local membrane midpoint in each patch,
-the assign leaflet membership based on distance in *z* to the local membrane
+large undulations, `AssignLeaflets` can account for this by creating a grid in :math:`xy`
+of your membrane, calculating the local membrane midpoint in each patch,
+then assigning leaflet membership based on distance in :math:`z` to the local membrane
 midpoint. This is done through use of `n_bins`::
 
   leaflets = AssignLeaflets(
@@ -329,3 +335,29 @@ class AssignLeaflets(base.AnalysisBase):
         ] = 0
         
         return None
+
+    def filter_leaflets(self, lipid_sel=None, frames=None):
+        """Create a subset of the leaflets results array.
+        
+        Filter either by lipid species or by the trajectory frames, or both.
+
+        Parameters
+        ----------
+        lipid_sel : str, optional
+            MDAnalysis selection string that will be used to select a subset of lipids present
+            in the leaflets results array. The default is `None`, in which case data for all lipids
+            will be returned.
+        frames : numpy.ndarray, optional
+            Array of trajectory frame numbers that will be used to create a subset of frames present
+            in the leaflets results array. The default is `None`, in which case data for all frames will
+            be returned.
+        """
+        
+        lipid_sel = "all" if lipid_sel is None else lipid_sel
+        lipids = self.membrane.residues.atoms.select_atoms(lipid_sel)
+        keep_lipids = np.in1d(self.membrane.residues.resindices, lipids.residues.resindices)
+        
+        frames = self.frames if frames is None else np.array(frames)
+        keep_frames = np.in1d(self.frames, frames)
+        
+        return self.leaflets[keep_lipids][:, keep_frames]
